@@ -115,7 +115,7 @@ class powerswitch:
             False = Success
             True = Fail
         """
-        self.geturl(url= 'outlet?%d=OFF' % outlet)
+        self.geturl(url= 'outlet?%d=OFF' % int(outlet))
         return self.status(outlet) != 'OFF'
     def on(self,outlet=0):
         """ Turn on power to an outlet 
